/*****************************************************************************
 *
 * INTEL CORPORATION PROPRIETARY INFORMATION
 * This software is supplied under the terms of a license agreement
 * or non-disclosure agreement with Intel Corporation and may not be
 * copied nor disclosed except in accordance with the terms of that
 * agreement.
 * Copyright  2000-2003 Intel Corporation. All Rights Reserved.
 *
 *     $Workfile: ioctlcodes.h $
 *     $Revision: 1 $
 *     $Modtime: 1/10/05 11:29a $
 *      Author: Oleg Kuporosov
 *
 * ABSTRACT:
 *      This file contains definisions for IOCTL codes for AFE.
 *
 *      $History: ioctlcodes.h $
 * 
 * *****************  Version 1  *****************
 * User: Admin        Date: 1/17/05    Time: 4:57p
 * Created in $/PSTN_Modem/Layer2/linux/ham/serialdrv
 * Stubbed out linux diagnostics ioctl handler
 * By Tawade Prashant request
 * 
 * *****************  Version 36  *****************
 * User: Admin        Date: 11/12/04   Time: 4:11p
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * SCR 2995: SP: extension dialing failure if the application uses ATD for
 * extension dialing 
 * SCR 3028: TAM: call screening doesnt work 
 * SCR 3001: SP: Cant hear dialing sound 
 * SCR 3011: SP volume control has no effect in BVRP classic 
 * SCR 3042: Analog loopback test doesnt work 
 * SCR 3046: Mute button causes both mic and speaker muted. 
 * 
 * *****************  Version 35  *****************
 * User: Admin        Date: 7/21/04    Time: 4:24p
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * DSP<->AFE interface improvement
 * By Igor Ivanov request
 * 
 * *****************  Version 34  *****************
 * User: Okuporos     Date: 25.11.03   Time: 19:41
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * IOC_GET_RING_STATUS was added by Sergey Plotnikov.
 * 
 * *****************  Version 33  *****************
 * User: Okuporos     Date: 4.09.03    Time: 15:28
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * Support of 48 kHz audio redirection was implemented by Alexey Korolev
 * and Konstantin Nevidin.
 * 
 * *****************  Version 32  *****************
 * User: Admin        Date: 7/31/03    Time: 4:23p
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * Prtially fix of SCR 1689 "dynamic mic gain table selection based on
 * audio card name."
 * 
 * By Alexey Korolev request
 * 
 * *****************  Version 31  *****************
 * User: Admin        Date: 7/17/03    Time: 11:11a
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * Some comments were added. 
 * By Aleksey Alekseev request.
 * 
 * *****************  Version 30  *****************
 * User: Okuporos     Date: 27.06.03   Time: 15:27
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * IOCTL_SET_MANUAL_CALIBRATION was added.
 * 
 * *****************  Version 29  *****************
 * User: Okuporos     Date: 21.06.03   Time: 19:47
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * Bill's changes were rolled back, IsONHM to cardParams was added.
 * 
 * *****************  Version 27  *****************
 * User: Akorolex     Date: 3.06.03    Time: 16:41
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * AFE_AUDIO_CALLBACK_MIC & AFE_AUDIO_CALLBACK_SPK interfaces are added
 * 
 * *****************  Version 26  *****************
 * User: Akorolex     Date: 8.05.03    Time: 16:39
 * Updated in $/PSTN_Modem/Layer1/Catawba_1_7/include
 * New interfaces are added
 * 
 * *****************  Version 25  *****************
 * User: Admin        Date: 2/20/03    Time: 4:26p
 * Updated in $/PSTN_Modem/Layer1/Catawba_1_7/include
 * Device config IO control processing was added
 * By Aleksey Alekseev request
 * 
 * *****************  Version 24  *****************
 * User: Iivanov      Date: 14.02.03   Time: 11:20
 * Updated in $/PSTN_Modem/Layer1/Catawba_1_7/include
 * Line status monitor functionaly was implemented
 * 
 * *****************  Version 23  *****************
 * User: Iivanov      Date: 30.01.03   Time: 18:45
 * Updated in $/PSTN_Modem/Layer1/Catawba_1_7/include
 * AFE migration from PSTN_MODEM_2_2\Catawba to PSTN_MODEM\Catawba_1_7
 * 
 * *****************  Version 24  *****************
 * User: Okuporos     Date: 15.01.03   Time: 13:07
 * Updated in $/PSTN_Modem_2_2/Layer1/Catawba/include
 * Some comments were added.
 * 
 * *****************  Version 23  *****************
 * User: Akorolex     Date: 25.12.02   Time: 21:51
 * Updated in $/PSTN_Modem_2_2/Layer1/Catawba/include
 * IOCTL GET_TX_DEPTH has been removed
 * No need in it.
 * 
 * *****************  Version 22  *****************
 * User: Iivanov      Date: 23.12.02   Time: 14:53
 * Updated in $/PSTN_Modem_2_2/Layer1/Catawba/include
 * Diagnostic was added
 * 
 * *****************  Version 21  *****************
 * User: Akorolex     Date: 29.11.02   Time: 17:06
 * Updated in $/PSTN_Modem_2_2/Layer1/Catawba/include
 * AFE_GET_LOOP_CURRENT interface implemented
 * 
 * *****************  Version 20  *****************
 * User: Akorolex     Date: 19.11.02   Time: 21:13
 * Updated in $/PSTN_Modem_2_2/Layer1/Catawba/include
 * New interfaces were added
 * 
 * *****************  Version 17  *****************
 * User: Okuporos     Date: 8.05.02    Time: 22:07
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * IOCTLCODES_H was restored.
 * 
 * *****************  Version 16  *****************
 * User: Iivanov      Date: 19.04.02   Time: 19:28
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * ioctls for Audio open/close are added
 * 
 * *****************  Version 15  *****************
 * User: Iivanov      Date: 28.03.02   Time: 11:27
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * IOC_GET_FEATURES is replaced with IOC_GET_STATE
 * 
 * *****************  Version 14  *****************
 * User: Iivanov      Date: 21.02.02   Time: 12:25
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 *  AFE_GET_CARDPARAM is added
 * 
 * *****************  Version 13  *****************
 * User: Okuporos     Date: 7.02.02    Time: 13:35
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * IOC_RESET was added.
 * 
 * *****************  Version 10  *****************
 * User: Akorolex     Date: 26.12.01   Time: 13:24
 * Updated in $/PSTN_Modem/Layer1/Catawba/include
 * IOC_AUDIO_ISRENDER       
 * IOC_AUDIO_ISCAPTURE      
 * IOC_AUDIO_START_RENDER 
 * IOC_AUDIO_STOP_RENDER      
 * IOC_AUDIO_START_CAPTURE    
 * IOC_AUDIO_STOP_CAPTURE 
 * IOC_AUDIO_WRITE_STREAM   
 * IOC_AUDIO_READ_STREAM    
 * 
 * *****************  Version 3  *****************
 * User: Iivanov      Date: 10.10.01   Time: 16:40
 * Updated in $/Catawba/src/AFE/hardware
 * Making up code
 * 
 * *****************  Version 2  *****************
 * User: Iivanov      Date: 17.07.01   Time: 16:07
 * Updated in $/Catawba/src/AFE/hardware
 * IOC_GET_DAA_VERSION was added
 * 
 * *****************  Version 11  *****************
 * User: Iivanov      Date: 7.06.01    Time: 15:16
 * Updated in $/Catawba/src/AFE/include
 * Caller Id was added
 * 
 * *****************  Version 10  *****************
 * User: Iivanov      Date: 21.05.01   Time: 10:57
 * Updated in $/Catawba/src/AFE/include
 * Power was added
 * 
 * *****************  Version 9  *****************
 * User: Akryukov     Date: 21/03/01   Time: 16:43
 * Updated in $/Catawba/src/AFE/include
 * two ioctl codes are replaced by
 * IOC_SET_AFE_REG
 * IOC_GET_AFE_REG
 * 
 * *****************  Version 7  *****************
 * User: Okuporos     Date: 23.02.01   Time: 11:29
 * Updated in $/Catawba/src/AFE/include
 * IOCTL_AFE_SET_REG was established.
 * 
 * *****************  Version 6  *****************
 * User: Okuporos     Date: 9.02.01    Time: 16:30
 * Updated in $/Catawba/src/AFE/include
 * IOC_SET_GET_DMABUF were deleted
 * 
 * *****************  Version 5  *****************
 * User: Akryukov     Date: 17/01/01   Time: 12:42
 * Updated in $/Catawba/src/AFE/include
 * IOC_SET_OR_GET_TJ_REG is added
 *****************************************************************************/
#ifndef IOCTLCODES_H
#define IOCTLCODES_H

#define IOC_CODE( IocType, Function ) (((IocType) << 8) | (Function))
#define IOC_TYPE_FROM_IOC_CODE(iocCode)     (((uint16)(iocCode & 0xFF00)) >> 8)
#define IOC_CARD                 0
#define IOC_AUDIO                1
#define IOC_GENERAL              2

#define IOC_ALLOCATE_BUFFERS    IOC_CODE( IOC_CARD, 0x30 ) 
#define IOC_FREE_BUFFERS        IOC_CODE( IOC_CARD, 0x31 ) 
#define IOC_GET_TXBUF_ADDR      IOC_CODE( IOC_CARD, 0x32 )
#define IOC_GET_RXBUF_ADDR      IOC_CODE( IOC_CARD, 0x33 )
#define IOC_SET_TXBUF_DATA      IOC_CODE( IOC_CARD, 0x34 )
#define IOC_GET_RXBUF_DATA      IOC_CODE( IOC_CARD, 0x35 )
#define IOC_GET_AFE_8BIT_REG    IOC_CODE( IOC_CARD, 0x36 )
#define IOC_SET_AFE_8BIT_REG    IOC_CODE( IOC_CARD, 0x37 )
#define IOC_GET_AFE_32BIT_REG   IOC_CODE( IOC_CARD, 0x38 )
#define IOC_SET_AFE_32BIT_REG   IOC_CODE( IOC_CARD, 0x39 )
#define IOC_GET_AFE_8BIT_MEM    IOC_CODE( IOC_CARD, 0x3A )
#define IOC_SET_AFE_8BIT_MEM    IOC_CODE( IOC_CARD, 0x3B )
#define IOC_GET_AFE_32BIT_MEM   IOC_CODE( IOC_CARD, 0x3C )
#define IOC_SET_AFE_32BIT_MEM   IOC_CODE( IOC_CARD, 0x3D )
#define IOC_GET_AFE_CONFIG_DATA IOC_CODE( IOC_CARD, 0x3E )
#define IOC_SET_AFE_CONFIG_DATA IOC_CODE( IOC_CARD, 0x3F )

#endif /* IOCTLCODES_H */
